@@ -24,7 +24,7 @@
    02111-1307, USA  */
 
 /****************************************************************************
-** $Id: secqstring.cpp,v 1.1 2003/12/19 23:28:11 marcus Exp $
+** $Id: secqstring.cpp,v 1.2 2004/01/18 18:10:04 marcus Exp $
 **
 ** Implementation of the SecQString class and related Unicode functions
 **
@@ -65,8 +65,6 @@
 
 #include "secqstring.h"
 
-#include "private/qunicodetables_p.h"
-
 static uint computeNewMax( uint len )
 {
     uint newMax = 4;
@@ -901,7 +899,7 @@ bool SecQString::isRightToLeft() const
     int len = length();
     QChar *p = d->unicode;
     while ( len-- ) {
-	switch( ::direction( *p ) )
+	switch( (*p).direction () )
 	{
 	case QChar::DirL:
 	case QChar::DirLRO:
